@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbmatch.pl,v 2.3 1998/07/15 18:01:25 joao Exp $
+# $Id: dbmatch.pl,v 2.5 1999/01/11 09:08:29 roman Exp $
 #
 #	$RCSfile: dbmatch.pl,v $
-#	$Revision: 2.3 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:25 $
+#	$Revision: 2.5 $
+#	$Author: roman $
+#	$Date: 1999/01/11 09:08:29 $
 #
 #	looks up the offsets in the dbm file for all keys
 #       and will return an array with the intersection of all
@@ -37,11 +37,12 @@
 
 require "defines.pl";
 require "enukey.pl";
+require "dpr.pl";
 
 sub dbmatch {
     local(*db, *allkeys, $types, $options) = @_;
+    &dpr("\@allkeys = (", join(" ", @allkeys), ") \$types = $types\n");
 
-    # print STDERR "db contents: ", $db{"bl2-test"}, "\n";
 
     local(%tmp)=();
     local(%nonsplitkeys)=();
@@ -67,10 +68,11 @@ sub dbmatch {
        }
           
     }
-    
+#    &dpr("\@classlesstype = (", join(" ", @classlesstypes), ")\n");
+
     foreach $key (@keys) {
-       
-       print STDERR "dbmatch - key: -$key- value: $db{$key} options: $options\n" if ($opt_V);
+
+	&dpr("\$key = $key, \$db{\$key} = $db{$key}, \$options = $options\n");
         
        if ($key=~ /^$VALIDPREFIXKEY$/o) {
           
@@ -79,9 +81,8 @@ sub dbmatch {
           if (@classlesstypes) {
              %alldbs=();
              @alldbs{@classlesstypes}=(1) x scalar(@classlesstypes);
-             
-             # print STDERR keys %alldbs, values %alldbs, "\n";
-             
+#             &dpr("\%alldbs keys: (", join(" ", keys %alldbs), ")",
+#		  "\%alldbs vals: (", join(" ", values %alldbs), ")\n");
           }
           
           #
@@ -102,12 +103,10 @@ sub dbmatch {
                 @classlesskeys=&findlsps(*mspnxl, $key, ($options & $ALLLESSSPECIFICOPTION));
                 
              }
-             
+#             &dpr("\@classlesskeys = (", join(" ", @classlesskeys), ")\n");
              @newkeys=grep(++$entry{$_}==1, &cla2unikey(*mspnxl, @classlesskeys));
-             
-             # print STDERR "newkeys: ", join(" ", @newkeys), "\n";
-             
-             #
+#             &dpr("\@newkeys = (", join(" ", @newkeys), ")\n");
+
              # this is to get non-split databases have the same behavior
              # as split databases
           
@@ -271,13 +270,13 @@ sub dbmatch {
           @newkeys=($key);
        }
 
-       #print STDERR "new: ", @newkeys, "\n";
+	&dpr("\@newkeys = (", join(" ", @newkeys), ")\n"); 
        	
        foreach (@newkeys) {
 	
 	  @offsets=split("\,", &getvalues(*db, $_));
-	  
-	  # print STDERR "offsets: ", @offsets, "\n";
+
+	  &dpr("\@offsets = (", join(" ", @offsets), ")\n"); 
 	  
 	  return () if ((!$classless) && ($options & $EXACTMATCHOPTION) && (!@offsets));
           
@@ -287,22 +286,24 @@ sub dbmatch {
 	      ($options & $INTERSECTIONOPTION) &&
 	      (!((scalar(@newkeys)>1) && (@classlesstypes))) &&
 	      (!($options & ($ALLMORESPECIFICOPTION | $ALLLESSSPECIFICOPTION)))) {
-	     
+	      &dpr("doing intersection\n");
 	     if (@result) {
+		 &dpr("before intersection, \@result = (", join(" ", @result), ")\n");
 	     	%tmp=();
 		grep($tmp{$_}++, @offsets);
 		@result=grep($tmp{$_}, @result);
-		
+		 &dpr("after intersection, \@result = (", join(" ", @result), ")\n");
 	     }
 	     else {
 		@result=@offsets;
+		&dpr("intersection, \@result = (", join(" ", @result), ")\n");
 	     }
 	     
 	     return () if (!@result);
 	  
 	  }
 	  else {
-	  
+	      &dpr("doing union\n");
 	     push(@result, grep(!$tmp{$_}++, @offsets));
 	      
 	  }
@@ -310,7 +311,7 @@ sub dbmatch {
        }
        
     }
-    
+    &dpr("\@result = (", join(" ", @result), ")\n");
     return @result;
     
 }
