@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: dbupdate.pl,v 2.7 1998/07/15 18:01:26 joao Exp $
+# $Id: dbupdate.pl,v 2.9 1999/01/12 09:57:05 roman Exp $
 #
 #	$RCSfile: dbupdate.pl,v $
-#	$Revision: 2.7 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:26 $
+#	$Revision: 2.9 $
+#	$Author: roman $
+#	$Date: 1999/01/12 09:57:05 $
 
 #
 # This is a client that will update objects read from a file directly
@@ -35,13 +35,11 @@
 # and that it has a database associated to it ...
 
 
-BEGIN {
-  require "getopts.pl";
+require "getopts.pl";
+require "rconf.pl";
+require "processdata.pl";
+require "dpr.pl";
 
-  require "rconf.pl";
-
-  require "processdata.pl";
-}
 
 # Parse options:
 #
@@ -56,8 +54,9 @@ BEGIN {
 # -T                    - TEST database update, accept creation of maintainers
 #                         always, but give a warning that this is not the
 #                         case in the normal database
+# -b                    - print debug messages (activated with &dpr call)
 
-&Getopts('Am:MTvV');
+&Getopts('Am:MTvVb');
 
 #
 # Need this below for running perl in tainted mode.
@@ -71,20 +70,20 @@ $ENV{"IFS"} = "";
 
 $conffile=$ENV{"RIPEDBCNF"};
 $conffile= $RIPEConfig{DEFCONFIG} unless $conffile;
-print STDERR "dbupdate - reading config\n" if $opt_V;
+#&dpr("reading config\n");
 &rconf($conffile);
 
 #
 # run on low priority, whois server queries have an
 # higher priority
 
-lower_priority;
+&lower_priority();
 
 if ($opt_m) {
    $opt_M=1;
    $FROM=$opt_m;
    $REPLYTO=$FROM;
-   print STDERR "Treating as mail from $FROM\n" if ($opt_V);
+#   &dpr("Treating as mail from $FROM\n");
 }
 
 &dbupdate("", STDOUT);
