@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: defines.pl,v 2.4 1998/07/15 18:01:27 joao Exp $
+# $Id: defines.pl,v 2.6 1999/01/11 09:08:31 roman Exp $
 #
 #	$RCSfile: defines.pl,v $
-#	$Revision: 2.4 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:27 $
+#	$Revision: 2.6 $
+#	$Author: roman $
+#	$Date: 1999/01/11 09:08:31 $
 
 $OK		=	1;
 $NOK		=	0;
@@ -65,7 +65,7 @@ $MESSAGE[$E_HIER_AUTHFAIL] = "hierarchical authorisation failed, request forward
 $MESSAGE[$E_NOAUTOUPDATE] = "object cannot be updated\/deleted automatically\nthe to be updated\/deleted object doesn\'t contain\na ".$ATTL{"mb"}." line.\nplease contact \<$HUMAILBOX\> for updating this object";
 $MESSAGE[$E_GENERAL]    = "";
 $MESSAGE[$E_NOTNEW]     = "object already exists";
-$MESSAGE[$E_STILLREFERENCED] = "cannot delete object that is still referenced\nby other objects in one of the databases";
+$MESSAGE[$E_STILLREFERENCED] = "cannot delete object that is still referenced\nby other objects in the database";
 
 #
 # Return codes for syntax checking the objects
@@ -147,6 +147,7 @@ $NOOPOPTION=64;
 $FAILEDOPTION=128;
 $BACKWARDCOMPATIBILITYOPTION=256;
 $ASSIGNEDNICOPTION=512;
+$OVERRIDEINTEGRITY=1024;
 
 #
 # donetdbm (binary) options
@@ -165,6 +166,7 @@ $NONRECURSIVEOPTION=16;
 $FASTOPTION=32;
 $NOSYNTACTICSUGAR=64;
 $EXACTMATCHOPTION=128;
+$NONREFERRALOPTION=256;
 
 #
 # The version of the inputformat we default to
