@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: hiermnt.pl,v 2.2 1998/07/15 18:01:31 joao Exp $
+# $Id: hiermnt.pl,v 2.4 1999/01/11 09:08:35 roman Exp $
 #
 #	$RCSfile: hiermnt.pl,v $
-#	$Revision: 2.2 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:31 $
+#	$Revision: 2.4 $
+#	$Author: roman $
+#	$Date: 1999/01/11 09:08:35 $
 
 # hiermnt.pl - implements the hierarchical authorization methods
 # it works only for creation right now...
@@ -39,6 +39,7 @@
 
 require "notify.pl";
 require "entype.pl";
+require "dpr.pl";
 
 sub HierarchicalAuthorization {
     local(*db,*OldObject,*NewObject,$type, $options)=@_;
@@ -55,7 +56,7 @@ sub HierarchicalAuthorization {
     
        if ($options & $NEWOPTION) {
        
-          print STDERR "hiermnt - hierarchial authorization (create: $type)\n" if $opt_V;
+#          &dpr("hierarchial authorization (create: $type)\n");
        
           if ($type eq "in") {
        
@@ -90,21 +91,21 @@ sub DoHierarchicalAuthorization {
     local(%directabove);
     local($key);
 
-    print STDERR "DoHierAuth: keys: ".join(" ",@keys)."\n" if ($opt_V);
+#    &dpr("keys: ".join(" ",@keys)."\n");
     
     foreach $key (&dbmatch(*db, *keys, "", 0)) {
        
        &enread($db, *directabove, $key);
         
-       print STDERR "DoHierAuth - hierarchical offset=$key, object=", $directabove{$type}, "\n"  if $opt_V;
+#       &dpr("hierarchical offset=$key, object=", $directabove{$type}, "\n");
  
        # check the type, we might have a non-split database!
  
-       if ($type eq &entype(*directabove)) {
+       if ($type eq &entype(%directabove)) {
        
           $returncode=$O_OK;
             
-          print STDERR "DoHierAuth - hierarchical last step ml=", $directabove{"ml"}, "...\n" if $opt_V;
+#          &dpr("hierarchical last step ml=", $directabove{"ml"}, "...\n");
           
           if ($directabove{"ml"}) {
           
@@ -138,13 +139,13 @@ sub AuthorizeInetnum {
      
     $directabove{$type}=$value;
     
-    print STDERR "hiermnt - hierarchical inetnum direct above=",$directabove{$type},"\n" if $opt_V;
+#    &dpr("hierarchical inetnum direct above=",$directabove{$type},"\n");
     
     local(@keys,@other,@pointsto,@otherspointsto,@classless);
     
     &enkeys(*directabove, $KEYS{$type}, *keys, *other, *pointsto, *otherspointsto, *classless, 1);
     
-    print STDERR "hiermnt - hierarchical inetnum keys=", join(" ", @classless) ,"\n"  if $opt_V;
+#    &dpr("hierarchical inetnum keys=", join(" ", @classless) ,"\n");
     
     #
     # we don't have time for sophisticated routines now
@@ -167,7 +168,8 @@ sub AuthorizeInetnum {
     
     }
     
-    print STDERR "hiermnt - hierarchical inetnum lessspecifics=", join(" ", @lessspecifics) ,"\n"  if $opt_V;
+#    &dpr("hierarchical inetnum lessspecifics=", 
+#	 join(" ", @lessspecifics) ,"\n");
     
     #
     # remove doubles (grep perl trick, see camel book)
@@ -176,7 +178,8 @@ sub AuthorizeInetnum {
     grep($tmp{$_}++, @lessspecifics);
     @lessspecifics=keys(%tmp);
     
-    print STDERR "hiermnt - hierarchical inetnum after removing doubles lessspecifics=", join(" ", @lessspecifics) ,"\n"  if $opt_V;
+#    &dpr("hierarchical inetnum after removing doubles lessspecifics=", 
+#	 join(" ", @lessspecifics) ,"\n");
     
     #
     # find the smallest objects that are bigger then the current object
@@ -188,7 +191,7 @@ sub AuthorizeInetnum {
     
     $size=&quad2int("255.255.255.255",1);
     
-    print STDERR "start size: $size\n" if $opt_V;
+#    &dpr("start size: $size\n");
     
     foreach $key (@lessspecifics) {
        
@@ -201,7 +204,7 @@ sub AuthorizeInetnum {
        
           ($newtype, %foundobject)=&uniquekey2entry($uniquekey);
           
-          print STDERR "newtype: $newtype name: ",$foundobject{$newtype},"\n" if $opt_V;
+#          &dpr("newtype: $newtype name: ",$foundobject{$newtype},"\n");
        
           #
           # don't use objects with another type, this is for non split databases
@@ -210,7 +213,7 @@ sub AuthorizeInetnum {
           
              ($newrange, $code)=&normalizerange($foundobject{$type}, $type);
           
-             print STDERR "newrange: $newrange code: $code\n" if $opt_V;
+#             &dpr("newrange: $newrange code: $code\n");
              
              ($ip1,$ip2)=split(/ *\- */, $newrange);
        
@@ -223,14 +226,14 @@ sub AuthorizeInetnum {
              
                 if ($newsize==$size) {
                 
-                   print STDERR "same size: $newsize\n" if $opt_V;
+#                   &dpr("same size: $newsize\n");
                 
                    push(@directabove,$key);   
                 
                 }
                 else {   
                 
-                   print STDERR "newsize: $newsize\n" if $opt_V;
+#                   &dpr("newsize: $newsize\n");
                 
                    $size=$newsize;
                    @directabove=($key);
@@ -267,7 +270,7 @@ sub AuthorizeDomain {
     
     if (($domain!~ /\./) && ($options & $NEWOPTION)) {
        
-       $returncode=$E_HIER_AUTHFAIL;
+       return $E_HIER_AUTHFAIL;
 
     }
     
@@ -279,11 +282,12 @@ sub AuthorizeDomain {
              
        $directabove{$type}=$1;
        
-       print STDERR "hiermnt - hierarchical domain direct above=",$directabove{$type},"\n" if $opt_V;
+#       &dpr("hiermnt - hierarchical domain direct above=",
+#	    $directabove{$type},"\n");
        
        &enkeys(*directabove, $KEYS{$type}, *keys, *other, *pointsto, *otherspointsto, *classless, 0);
        
-       print STDERR "hiermnt - hierarchical domain keys=", join(" ", @keys) ,"\n"  if $opt_V;
+#       &dpr("hiermnt - hierarchical domain keys=", join(" ", @keys) ,"\n");
        
        $code=&DoHierarchicalAuthorization(*db, $options, $type, *OldObject, *NewObject, *keys);
        
@@ -293,7 +297,7 @@ sub AuthorizeDomain {
     
     # we didn't find a parent object
     
-    return $E_HIER_AUTHFAIL;   
+    return $O_OK;
           
 }    
 
