@@ -21,12 +21,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: maintainer.pl,v 2.5 1998/07/15 18:01:33 joao Exp $
+# $Id: maintainer.pl,v 2.6 1998/12/09 14:39:18 roman Exp $
 #
 #	$RCSfile: maintainer.pl,v $
-#	$Revision: 2.5 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:33 $
+#	$Revision: 2.6 $
+#	$Author: roman $
+#	$Date: 1998/12/09 14:39:18 $
 
 # There is a few global variables it will use for authorisation:
 # 
@@ -48,6 +48,7 @@
 require "notify.pl";
 require "entype.pl";
 require "hiermnt.pl";
+require "dpr.pl";
 
 # %CurMaintainer and %ExistMaintainer seem to be local to this file
 # and used by various subs within it.
@@ -58,8 +59,10 @@ sub Maintainer {
     
     local($mntners, $mntner);
     
-    print STDERR "Maintainer - (othermntners=$othermntners, newmb: ", $NewObject{"mb"}, ", oldmb: ", $OldObject{"mb"},")\n" if $opt_V;
-    
+#    &dpr("othermntners=$othermntners, newmb: ", 
+#	 $NewObject{"mb"}, ", oldmb: ", $OldObject{"mb"},"\n");
+#    &dpr("override option: ", ($options & $OVERRIDEOPTION), "\n");
+
     if ($othermntners) {
        $mntners=$othermntners; 
     } 
@@ -79,6 +82,23 @@ sub Maintainer {
 	
     return 1 if (!$mntners);
 
+    # special case - adding maintainers to the TEST database
+    # which are maintained by themselves - skip authorization
+
+    if (($options & $NEWOPTION) && 
+	($opt_T)               &&
+	($mntners =~ /$NewObject{"mt"}/)) {
+
+	# Notify maintainers
+	if ($othermntners) {
+	    &NotifyMaintainers(*OldObject, *NewObject, $othermntners);
+	}
+	else {
+	    &NotifyMaintainers(*OldObject, *NewObject, "");
+	}	
+	return 1;
+    }
+
     #
     # check authorization if no override
 
@@ -88,8 +108,6 @@ sub Maintainer {
 
        foreach $mntner (split(/\s+/, $mntners)) {
 
-          print STDERR "maintainer - maintainer: $maintainer\n" if ($opt_V);
-	  
           if ($options & $NEWOPTION) {  
              last if (($status=&VrfyMaint($mntner, *NewObject)));
           }
@@ -132,6 +150,12 @@ sub Maintainer {
     
 }
 
+# GetMaintainer($maintainername, $source, $lognotexistingmntners)
+#
+# Get maintainer object from database. As a "side effect" sets
+# global variables %ExistMaintainer and %CurMaintainer which are
+# also used outside of this function.
+
 sub GetMaintainer {
     local($maintainername, $source, $lognotexistingmntners) = @_;
     local($mntdb)='mntdb';
@@ -143,7 +167,7 @@ sub GetMaintainer {
 
     local(@keys) = ($normalized);
 
-    return 1 if ($CurMaintainer{"mt"} eq $maintainername);
+    return %CurMaintainer if ($CurMaintainer{"mt"} eq $maintainername);
 
     if ($SPLIT{$source}) {
 	$dbfile = "$DBFILE{$source}.mt";
@@ -157,7 +181,7 @@ sub GetMaintainer {
 		    "maintainer: $maintainername\n");
 	    # Set error, should not happen!!!!!
 	    &dbclose(*mntdb);
-	    return 0;
+	    return undef;
 	}
 	if (!$matches[0]) {
 	    &syslog(
@@ -165,31 +189,30 @@ sub GetMaintainer {
 		    "GetMaintainer() no match found for maintainer $maintainer"
 		    ) if ($lognotexistingmntners);
 	    &dbclose(*mntdb);
-	    return 0;
+	    return undef;
 	}
 	&enread($mntdb, *CurMaintainer, $matches[0]);
 	$ExistMaintainer{$CurMaintainer{"mt"}} = 1;
 	&dbclose(*mntdb);
-	return 1;
+	return %CurMaintainer;
     }
     else {
 	&syslog("ERRLOG",
 		"GetMaintainer - failed to open $DBFILE{$source}.mt\n"
 		);
-	return 0;
+	return undef;
     }
 }
 
+# This routine gets the maintainer object and looks at the auth fields
+# Calls different routines depending on auth method
 sub VrfyMaint {
     local($maintainer, *object) = @_;
     local($status);
     local($source) = $object{"so"};
 
-    print STDERR "VrfyMaint - maintainer: $maintainer\n" if ($opt_V);
-
     if (&GetMaintainer($maintainer, $source,1)) {
 	foreach (split(/\n/, $CurMaintainer{"at"})) {
-	    print STDERR "VrfyMaint - vrfy: $_\n" if ($opt_V);
 	    $status = 0;
 	    if ($_ eq "NONE") {
 		return 1;
@@ -204,6 +227,11 @@ sub VrfyMaint {
 		return 1 if $status;
 		next;
 	    }
+            if ($_ =~ /PGPKEY/) {
+                $status = &CheckPGP($_);
+                return 1 if $status;
+                next;
+            }
 	}
 	return $status;
     }
@@ -221,7 +249,7 @@ sub CheckMailFrom {
     local($regex) = $1;
     $regex =~ s/\\?\@/\Q\@\E/g;   # quote '@'s for perl5
     
-    print STDERR "CheckMailFrom - $FROM=~ /$regex/\n" if ($opt_V);
+#    &dpr("$FROM=~ /$regex/\n");
 
     # case insensitive match
     return 1 if $FROM =~ /$regex/i;
@@ -241,6 +269,33 @@ sub CheckPassword {
     return 0;
 }
 
+#
+# Check PGP authentication
+#
+
+sub CheckPGP {
+   my ($line)=@_;
+   my $key;
+
+   unless ($line =~ /PGPKEY-([0-9a-fA-F]{8})/) {
+     return 0;
+   }
+   $key = $1;
+
+   print "In CheckPGP. Message KEYID = $Main::KEYID, Mntner KEYID = $key\n" 
+       if ($opt_V);
+
+   if (!defined($PGP_signed)) {
+     &syslog("AUDITLOG","Auth PGP failed. (No signature?)");
+     return 0;
+   }
+   if ($PGP_signed ne $key) {
+     &syslog("AUDITLOG","Auth PGP failed. Wrong KEYID: $PGP_signed vs $key");
+     return 0;
+   }
+   return 1;
+}
+
 #
 # This routine will handle the mnt-nfy function in the maintainer object
 # It will extract the email addresses from mnt-nfy attribute, and from
@@ -310,12 +365,12 @@ sub ForwardToMaint {
     
     local($line);
     local(@maintainers) = ();
-    local($oldtype) = &entype(*OldObject);
-    local($newtype) = &entype(*NewObject);
+    local($oldtype) = &entype(%OldObject);
+    local($newtype) = &entype(%NewObject);
     local($source);
     local($email,$regularemail);
     
-    print STDERR "ForwardToMaint - forwarding othermntners=$othermntners\n" if $opt_V;
+#    &dpr("forwarding othermntners=$othermntners\n");
     
     if ($othermntners) {
 
