@@ -20,17 +20,18 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: notify.pl,v 2.7 1998/07/15 18:01:35 joao Exp $
+# $Id: notify.pl,v 2.8 1998/12/09 14:39:20 roman Exp $
 #
 #	$RCSfile: notify.pl,v $
-#	$Revision: 2.7 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:35 $
+#	$Revision: 2.8 $
+#	$Author: roman $
+#	$Date: 1998/12/09 14:39:20 $
 
 
 require "encmp.pl";
 require "enwrite.pl";
 require "entype.pl";
+require "dpr.pl";
 
 # It consists of two parts. One is the part that writes out the objects
 # to temp files, one temp file per notifier, and this is called from
@@ -99,7 +100,7 @@ sub DoAddNotify {
 
     foreach $notify (@notifiers) {
         
-        print STDERR "notifier: $notify\n" if ($opt_V);
+#        &dpr("notifier: $notify\n");
         
         #
         # skip doubles
@@ -118,13 +119,12 @@ sub DoAddNotify {
 
 	  my ($match) = ($REPLYTO=~ /$regularnotify/);
 
-	  print STDERR "DoAddNotify: ",
-	               "notifiee [$notify], ",
-	               "sender [$REPLYTO], ",
-	               "regexp [$regularnotify]",
-	               "match [$match]",
-	               "\n"
-			 if $opt_V;
+#	  &dpr("DoAddNotify: ",
+#	       "notifiee [$notify], ",
+#	       "sender [$REPLYTO], ",
+#	       "regexp [$regularnotify]",
+#	       "match [$match]",
+#	       "\n");
 
 	  if ($match) {
 	    if ($SUPPRESSMESS eq 'NOTIFY') {    # suppress notification
@@ -206,7 +206,7 @@ sub SendNotifications {
 
     foreach (values %notify) {
        system("$MAILCMD < $_");
-       print STDERR "notify: $_\n" if ($opt_V);
+#       &dpr("notify: $_\n");
     }
     
     unlink(values %notify);
