@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: processdata.pl,v 2.11 1998/07/15 18:01:36 joao Exp $
+# $Id: processdata.pl,v 2.13 1999/01/11 09:08:38 roman Exp $
 #
 #	$RCSfile: processdata.pl,v $
-#	$Revision: 2.11 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:36 $
+#	$Revision: 2.13 $
+#	$Author: roman $
+#	$Date: 1999/01/11 09:08:38 $
 
 
 @INC = ("LIBDIR", @INC);
@@ -42,6 +42,7 @@ require "misc.pl";
 require "rconf.pl";
 require "rfc822.pl";
 require "syslog.pl";
+require "dpr.pl";
 
 
 #
@@ -53,8 +54,6 @@ require "syslog.pl";
 sub printstat {
     local($output, *entry, $type, $options) = @_;
 
-    print STDERR "dbupdate - printstat($FROM,$options) called\n" if $opt_V;
-
     if ($options & $DELETEOPTION) {
        print $output "Delete ";
     }
@@ -110,27 +109,25 @@ sub processdata {
     local($type,$key,$value,$reordered,$dbstat,$parsestat);
     local($options,$codes,$overrideattr,$deleteattr,@autonichandles);
 
-    print STDERR "processdata - ($FROM,$input) called\n" if $opt_V;
+    &dpr("\$FROM = $FROM, \$input = $input, \$output = $output\n");
     
     while(1) {
 
-	print STDERR "processdata - calling enparse\n" if $opt_V;
-        
 	($parsestat, $type, %entry)=&enparse($input) if (!$eof);
 	
-	print STDERR "processdata - left parse: $parsestat $type\n" if ($opt_V);
+#	&dpr("enparse returned: \$parsestat = $parsestat, \$type = $type\n");
+#	&dpr("+++++++++++++++++++++++++++\n");
+#	&dpr("\%entry = " . join("*", %entry) . "\n");
+#	&dpr("---------------------------\n");
 	
 	$eof=1 if ($parsestat==$EOF);
 	
-	#
 	# get objects from the queue if we reached EOF
 	
 	if ($eof) {
 	   
 	   if (@queue) {
 	      
-	      # print STDERR "queue:\n", join("\n", @queue), "-\n";
-	      
 	      $parsestat=shift(@queue);
 	      $type=shift(@queue);
 	      @autonichandles=split(" ", shift(@queue));
@@ -143,7 +140,6 @@ sub processdata {
 	          
 	      }
 	      
-	      
 	   }
 	   else {
 	      
@@ -161,7 +157,7 @@ sub processdata {
         
         $somethingfound=1;
         
-	print STDERR "dbupdate - read an object ($parsestat,$entry{$type})\n" if $opt_V;
+#	&dpr("read an object ($parsestat,$entry{$type})\n");
 
         if ($parsestat==$O_ERROR) {
            
@@ -180,13 +176,14 @@ sub processdata {
 	   }
 	
 	   if (defined($entry{"uo"})) {
-	
-	      $options|=$OVERRIDEOPTION;
-	      $overrideattr=delete($entry{"uo"});
-	                    
+	       &dpr("override entry: ".$entry{"uo"}."\n");
+	       $options |= $OVERRIDEOPTION;
+	       $options |= $OVERRIDEINTEGRITY 
+		   if ($entry{"uo"} =~ /integrity/i);
+	       $overrideattr = delete($entry{"uo"});
 	   }
 	   else {
-	      $overrideattr=undef;
+	      $overrideattr = undef;
 	   }
            
         }
@@ -305,10 +302,11 @@ sub processdata {
 	   }
 	
 	   if (defined($entry{"uo"})) {
-	
-	      $options|=$OVERRIDEOPTION;
-	      $overrideattr=delete($entry{"uo"});
-	                    
+	       &dpr("override entry: ".$entry{"uo"}."\n");
+	       $options |= $OVERRIDEOPTION;
+	       $options |= $OVERRIDEINTEGRITY 
+		   if ($entry{"uo"} =~ /integrity/i);
+	       $overrideattr = delete($entry{"uo"});
 	   }
         
            #
@@ -317,7 +315,7 @@ sub processdata {
 	
 	   ($dbstat, $codes) =&finalchecksandupdate(*entry, $type, *autonichandles, *options);
 	   
-	   print STDERR "finalchecksandupdate - left ($FROM,$dbstat, $codes)\n" if ($opt_V);
+#	   &dpr("left ($FROM,$dbstat, $codes)\n");
 
 
 	}
@@ -368,7 +366,7 @@ sub processdata {
 	}
 	elsif (&haserror(*entry)) {
 	
-	   print STDERR "dbupdate - object has error\n" if $opt_V;
+#	   &dpr("object has error\n");
 	   
 	   $haserror++;
 	   
@@ -380,7 +378,7 @@ sub processdata {
 	elsif (&haswarning(*entry)) {
 	   
 	   &printstat($output, *entry, $type, $options | $OKOPTION);
-	   &enwrite($output,*entry,1,1,1);
+ 	   &enwrite($output,*entry,1,1,1);
 	   print $output "\n";
 	   
 	}
@@ -407,19 +405,122 @@ sub dbupdate {
 
     $Main::is_update=1;
 
-    #
-    # We want to make a local copy of the input, because we need to do multiple
-    # things with it ...
+    # We want to make a local copy of the input, because we need to do
+    # multiple things with it... also we want to separate PGP signed
+    # parts from the original message to be fed to PGPV for checking.
+
+    my($copyfile_unsigned) = $TMPDIR . "/dbupdcopy.$$";
+    my(@copyfiles_signed);
+
+    open(COPY, "+>$copyfile_unsigned")
+	or fatalerror("Cannot create $copyfile_unsigned: $!");
+
+    my(@input);
 
-    local($copyfilename)=$TMPDIR."\/dbupdcopy.".$$;
-    
-    open(COPY, "+>".$copyfilename) || &fatalerror("Cannot create $copyfilename: $!");
     if ($input) {
-       print COPY $input;
+      @input = split(/\n/, $input);
+    } 
+
+    # log a copy of the message to UPDLOG before we process it
+
+    # This may seem yucky, but is needed to untaint the filename ...
+    {
+      my($filename) = $LOGFILE{"UPDLOG"}."/".$DATE;
+      $filename =~ /(.*)/;
+      $realfile = $1;
+    }
+
+    if (open(LOG, ">>$realfile")) {
+      &appendlock(LOG);
+    
+      if ($opt_M) {
+        print LOG "\n>>> time: $TIME MAIL UPDATE <<<\n\n";
+      } 
+      elsif ($NETWORKUPDATE) {
+        print LOG "\n>>> time: $TIME $NETWORKUPDATE NETWORK UPDATE <<<\n\n";
+      }
+      else {
+        print LOG "\n>>> time: $TIME STDIN UPDATE <<<\n\n";
+      }
     }
     else {
-       print COPY <>;
+      &syslog("ERRLOG", "dbupdate cannot open $realfile"); 
     }
+
+    my($cpst) = 0; # 0 = unsigned, 1 = signed data, 2 = signature
+		   # 3 = encoded message
+
+    while (1) {
+      if ($input) {
+	last unless defined($_ = shift(@input));
+	$_ .= "\n";	# split above eats new-lines
+      } else {
+	last unless defined($_ = <>);
+      }
+      print LOG;
+
+      unless ($have_pgp) {
+	print COPY;
+	next;
+      }
+      if ($cpst == 0 && /^-----BEGIN PGP SIGNED MESSAGE-----$/) {
+	$cpst = 1;
+
+	my($copyfile_signed) = $TMPDIR . "/dbupdscopy.$$." . @copyfiles_signed;
+	push(@copyfiles_signed, $copyfile_signed);
+
+	open(PGPCOPY, ">$copyfile_signed")
+	    or fatalerror("Cannot create $copyfile_signed: $!");
+
+	# fall through
+      }
+      if ($cpst == 0 && /^-----BEGIN PGP MESSAGE-----$/) {
+	$cpst = 3;
+
+	my($copyfile_signed) = $TMPDIR . "/dbupdscopy.$$." . @copyfiles_signed;
+	push(@copyfiles_signed, $copyfile_signed);
+
+	open(PGPCOPY, ">$copyfile_signed")
+	    or fatalerror("Cannot create $copyfile_signed: $!");
+
+	# fall through
+      }
+      if ($cpst == 0) {
+	print COPY;
+	next;
+      }
+      if ($cpst == 1 && /^-----BEGIN PGP SIGNATURE-----$/) {
+	$cpst = 2;
+	# fall through
+      }
+      if ($cpst == 2 && /^-----END PGP SIGNATURE-----$/) {
+	$cpst = 0;
+	print PGPCOPY;
+	close(PGPCOPY);
+	next;
+      }
+      if ($cpst == 3 && /^-----END PGP MESSAGE-----$/) {
+	$cpst = 0;
+	print PGPCOPY;
+	close(PGPCOPY);
+	next;
+      }
+      if ($cpst == 1 || $cpst == 2 || $cpst == 3) {
+	print PGPCOPY;
+	next;
+      }
+      fatalerror("Unknown cpst state: $cpst (should not happen)");
+      last; # not reached?
+    }
+
+    # discard (last) signed part if it is not properly finished
+    if ($cpst != 0) {
+      close(PGPCOPY);
+      unlink(pop(@copyfiles_signed));
+    }
+
+    close(LOG);
+
     &flush(COPY);
     seek(COPY, 0, 0);
 
@@ -445,9 +546,10 @@ sub dbupdate {
     # We have a mail, so let's first parse the headers ...
 
     local($stat)=1;
+    undef @subj_ans;
 
     $stat=&parserfc822(COPY) if ((!$opt_m) && ($opt_M));
-    
+
     &ReplaceGlobalVars(*FWHEADER);
     &ReplaceGlobalVars(*FWTXT);
     &ReplaceGlobalVars(*FWMAILTXT);
@@ -488,11 +590,123 @@ sub dbupdate {
       
     } else {
 
+      #
+      # PGP signature state: undef if not signed, keyID if signed & ok
+      #
+
+      $PGP_signed = undef;
+
       #
       # Take all the stuff from file COPY in doaction. It will process the
       # whole stuff.
+      #
 
-      local($somethingfound, $haserror)=&processdata(COPY, ACK);
+      my($somethingfound, $haserror) = processdata(COPY, ACK);
+      close(COPY);
+
+      #
+      # Then we process the PGP signed parts
+      #
+
+      foreach $copyfile_signed (@copyfiles_signed) {
+	my($copyfile_signed_out) = $TMPDIR . "/dbupdscopyo.$$";
+	my($somethingfound_new, $haserror_new);
+
+	my($pgpsigstatus, $pgpsigid) = 
+	    checkPGPmsg($copyfile_signed, $copyfile_signed_out);
+
+	if (!defined($pgpsigstatus) || $pgpsigstatus == -1) { 
+	  # no signature found by PGP or PGP error
+	  # process the part as w/o signature (shouldn't happen?)
+          $PGP_signed = undef;
+
+	  if ($pgpsigstatus == -1) {
+	    print ACK "*** Cannot check PGP signed part: $pgpsigid\n\n";
+	    $haserror = $somethingfound = 1;
+	  }
+
+          open(SCOPY, $copyfile_signed)
+	      or fatalerror("Cannot open $copyfile_signed: $!");
+
+	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
+	  close(SCOPY);
+           
+	  $somethingfound = $somethingfound_new if $somethingfound_new;
+	  $haserror = $haserror_new if $haserror_new;
+	} elsif ($pgpsigstatus == 0) { # PGP signature not OK, ignore this part
+          $PGP_signed = undef;
+
+	  print ACK "*** Ignoring PGP signed part with BAD signature"
+	      . ($pgpsigid ? " from key ID $pgpsigid" : "") . "\n\n";
+	  $haserror = $somethingfound = 1;
+
+	} elsif ($pgpsigstatus == 1) { # signature by unknown keyID
+	  $PGP_signed = undef;
+
+	  print ACK "*** Beginning of PGP signed part "
+	      . "from *UNKNOWN* key ID $pgpsigid\n\n";
+	  $haserror = $somethingfound = 1;
+
+          open(SCOPY, $copyfile_signed_out)
+	      or fatalerror("Cannot open $copyfile_signed_out: $!");
+
+	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
+	  close(SCOPY);
+           
+	  $somethingfound = $somethingfound_new if $somethingfound_new;
+	  $haserror = $haserror_new if $haserror_new;
+
+	  print ACK "*** End of PGP signed part "
+	      . "from *UNKNOWN* key ID $pgpsigid\n\n";
+
+	} elsif ($pgpsigstatus == 2) { # PGP signature OK
+          $PGP_signed = $pgpsigid;
+
+	  print ACK "*** Beginning of PGP signed part "
+	      . "from key ID $pgpsigid\n\n";
+	  $somethingfound = 1;
+
+          open(SCOPY, $copyfile_signed_out)
+	      or fatalerror("Cannot open $copyfile_signed_out: $!");
+
+	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
+	  close(SCOPY);
+           
+	  $somethingfound = $somethingfound_new if $somethingfound_new;
+	  $haserror = $haserror_new if $haserror_new;
+
+	  print ACK "*** End of PGP signed part "
+	      . "from key ID $pgpsigid\n\n";
+
+	} elsif ($pgpsigstatus == 3) { # message encrypted & can't decrypt
+          $PGP_signed = undef;
+
+	  print ACK "*** Ignoring PGP encrypted part (can't decrypt)\n\n";
+	  $haserror = $somethingfound = 1;
+
+	} elsif ($pgpsigstatus == 4) { # message encrypted & can decrypt
+          $PGP_signed = undef;
+
+	  print ACK "*** Beginning of PGP encrypted part\n\n";
+	  $haserror = $somethingfound = 1;
+
+          open(SCOPY, $copyfile_signed_out)
+	      or fatalerror("Cannot open $copyfile_signed_out: $!");
+
+	  ($somethingfound_new, $haserror_new) = processdata(SCOPY, ACK);
+	  close(SCOPY);
+           
+	  $somethingfound = $somethingfound_new if $somethingfound_new;
+	  $haserror = $haserror_new if $haserror_new;
+
+	  print ACK "*** End of PGP encrypted part\n\n";
+
+	} else { # shouldn't ever happen :-)
+          fatalerror("Unknown PGP sig state: $pgpsigstatus (shouldn't happen)");
+	}
+	unlink($copyfile_signed_out);
+	$PGP_signed = undef;
+      }
 
       # rewind the ack file generated by processdata
       &flush(ACK);
@@ -545,7 +759,8 @@ sub dbupdate {
       } else {
 	push @ack, "*** No objects were found ***\n" unless ($NETWORKUPDATE);
       }
-
+      # include diagnostics from Subject: parser
+      push @ack, @subj_ans;    
     }
 
 #    if ($somethingfound) {
@@ -571,7 +786,7 @@ sub dbupdate {
     # We sent out the ack, now send out the notifications if needed
 
     if (%notify) {
-       print STDERR "dbupdate - sending notifications (", keys %notify,")\n" if ($opt_V);
+#       &dpr("sending notifications (", keys %notify,")\n");
        &SendNotifications();
     }
 
@@ -582,48 +797,10 @@ sub dbupdate {
     }
 
     if (%forward) {
-       print STDERR "dbupdate - sending forwards(", keys %forward, ")\n" if ($opt_V);
+#       &dpr("sending forwards(", keys %forward, ")\n");
        &SendForwardMails();
     }
 
-    #
-    # log all stuff to the right places
-
-    # This may seem yucky, but is needed to untaint the filename ...
-
-    $filename = $LOGFILE{"UPDLOG"}."/".$DATE;
-    $filename =~ /(.*)/;
-    $realfile = $1;
-
-    #
-    # first let's log the updates send in
-
-    if (open(LOG, ">>$realfile")) {
-    
-       &appendlock(LOG);
-    
-       if ($opt_M) {
-          print LOG "\n>>> time: $TIME MAIL UPDATE <<<\n\n";
-       } 
-       elsif ($NETWORKUPDATE) {
-          print LOG "\n>>> time: $TIME $NETWORKUPDATE NETWORK UPDATE <<<\n\n";
-       }
-       else {
-          print LOG "\n>>> time: $TIME STDIN UPDATE <<<\n\n";
-       }
-
-       &flush(COPY);
-       seek(COPY, 0, 0);
-       print LOG <COPY>;
-       close(LOG);
-   
-    }
-    else {
-      &syslog("ERRLOG", "dbupdate cannot open $LOGFILE{\"UPDLOG\"}/$DATE"); 
-    }
-
-    close(COPY);
-
     #
     # then we log the acknowledgement
 
@@ -633,7 +810,7 @@ sub dbupdate {
 
     if (open(LOG, ">>$realfile")) {
     
-       print STDERR "dbupdate - updating logs\n" if $opt_V;
+#       &dpr("updating logs\n");
     
        &appendlock(LOG);
     
@@ -670,26 +847,25 @@ sub dbupdate {
     # unless we have send a notify to the same address
 
     if ($opt_M) {
-      if ($::DontAck) {
-	print STDERR "dbupdate - notification to [$REPLYTO] ",
-	             "suppresses ack to [$::DontAck]\n"
-		       if $opt_V;
-	undef $::DontAck;
-      } else {
-	print STDERR "dbupdate - sending ack\n" if $opt_V;
+	if ($::DontAck) {
+#	    &dpr("dbupdate - notification to [$REPLYTO] ",
+#		 "suppresses ack to [$::DontAck]\n");
+	    undef $::DontAck;
+	} else {
+#	    &dpr("dbupdate - sending ack\n");
 #	system("$MAILCMD <".$ackfilename);
-	open(MAIL, "|$MAILCMD");
+	    open(MAIL, "|$MAILCMD");
 #	open(MAIL, "|/bin/cat");
-	print MAIL @ack;
-	close MAIL || warn "mail: $!"
+	    print MAIL @ack;
+	    close MAIL || warn "mail: $!"
 #	system("/bin/cat <".$ackfilename);
-      }
+	    }
     }
     
     #
     # remove the temp stuff we made
 
-    unlink($copyfilename, $ackfilename);
+    unlink($copyfile_unsigned, $ackfilename, @copyfiles_signed);
 
 }
 
