@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: rconf.pl,v 2.10 1998/07/15 18:01:37 joao Exp $
+# $Id: rconf.pl,v 2.12 1999/01/11 09:08:39 roman Exp $
 #
 #	$RCSfile: rconf.pl,v $
-#	$Revision: 2.10 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:37 $
+#	$Revision: 2.12 $
+#	$Author: roman $
+#	$Date: 1999/01/11 09:08:39 $
 #
 #       This routine reads all parameters from the configuration file
 #       into scalars or associative arrays of the same name (uppercase).
@@ -64,7 +64,7 @@ sub rconf {
     #
     # needed in several routines...
     
-    ($DATE,$TIME)=&getYYMMDDandHHMMSS(); 
+    ($DATE,$TIME)=&getYYYYMMDDandHHMMSS(); 
     
     #
     # set a safe umask
@@ -160,6 +160,14 @@ sub rconf {
 	      else {
 		 $INV{$type}=$_;
 	      }
+           }
+           elsif ($field eq "GEN") {
+             if ($GEN{$type}) {
+                $GEN{$type}=join(" ", $GEN{$type}, $_);
+             }
+             else {
+                $GEN{$type}=$_;
+             }
 	   }
            
            # print STDERR "-",$KEYS{$type}, "-\n";
@@ -168,27 +176,47 @@ sub rconf {
 
         }
         
-	if (/^ATTR\s+(..)\s+(\S+)\s+([^\s\#]+\s)?/) { 
+	if (/^ATTR\s+(..)\s+(\S+)  (\s+([^\s\#]+))? (\s+([^\s\#]+))?/x) { 
+#             |       |     ||     |   ||           |   ||           
+#             ATTR    tc    |tech-c|   |pn,ro       |   |nic
+#                     $1    $2     $3  $4           $5  $6
+#
 	   $ATTR{$1}=$1; $ATTR{$2}=$1; $ATTL{$1}=$2;
 	    
 	   $MAXATTRIBUTELENGTH=length($2) if (length($2)>$MAXATTRIBUTELENGTH);
 	    
-	   if ($3) {
-	      local($tag)=$1;
-	       
-	      $POINTSTO{$tag}=$3;
-	      $POINTSTO{$tag}=~ s/\s+$//;
-	      $POINTSTO{$tag}=~ s/\,/ /g;
+	   if ($4) {
+	      my($tag) = $1;
 	       
+	      $POINTSTO{$tag} = $4;
+	      $POINTSTO{$tag} =~ s/\s+$//;
+	      $POINTSTO{$tag} =~ s/\,/ /g;
 	   }
+	   if ($6) {
+	       my($tag) = $1;
 	    
+	       if ($6 eq 'nic') {
+		   $POINTSTONIC{$tag} = 1;
+	       }
+	       else {
+		   $POINTSTOMT{$tag} = 1;
+	       }
+	   }
+
 	   next;
 	   
 	}
 	
 	
-	if (/^GETUPDATESFROM\s+(\S.*\S)$/) { push(@GETUPDATESFROM,split(/\s+/,$1)); next; }
-	
+	if (/^GETUPDATESFROM\s+(\S.*\S)$/) { 
+	    push(@GETUPDATESFROM, split(/\s+/, $1)); next; 
+	}
+	if (/^DENYWHOISACCESS\s+(\S.*\S)$/) { 
+	    push(@DENYWHOISACCESS, split(/\s+/, $1)); next;
+	}
+	if (/^WHOISUPDFROM\s+(\S.*\S)$/) { 
+	    push(@WHOISUPDFROM, split(/\s+/, $1)); next; 
+	}
 	if (/^MAILTXT\s+(.*)/) { $MAILTXT.=$1."\n"; next;}
 	if (/^ACKSIG\s+(.*)/) { $ACKSIG=$ACKSIG.$1."\n"; next;}
 	if (/^RIGHTS\s+(.*)/) { $RIGHTS.=$1."\n"; next; }
@@ -213,10 +241,22 @@ sub rconf {
 	if (/^SUCCESSTXT\s+(.*)/) { $SUCCESSTXT.=$1."\n"; next;}
 	if (/^FAILURETXT\s+(.*)/) { $FAILURETXT.=$1."\n"; next;}
 	if (/^HELPHEADER\s+(.*)/) { $HELPHEADER.=$1."\n"; next;}
-		
-	if (/^WHOISUPDFROM\s+(\S.*\S)$/) { push(@WHOISUPDFROM,split(/\s+/,$1)); next; }
 	
-	if (/^ATTA\s+(..)\s+(\S*)/) { $ATTR{$2}=$1; next;}
+	if (/^ATTA\s+(..)\s+(\S*)/)  { $ATTR{$2}=$1; next;}
+	if (/^REFERRALTXT\s+(.*)/)   { $REFERRALTXT.=$1."\n"; next;}
+	if (/^DENYACCESSTXT\s+(.*)/) { $DENYACCESSTXT.=$1."\n"; next;}
+	if (/^REFERRALERRORTXT\s+(.*)/) { $REFERRALERRORTXT.=$1."\n"; next;}
+	if (/^REFERRALLOOPERRORTXT\s+(.*)/) 
+	    { $REFERRALLOOPERRORTXT.=$1."\n"; next;}
+	if (/^REFERRALTIMEOUTTXT\s+(.*)/) 
+	    { $REFERRALTIMEOUTTXT.=$1."\n"; next;}
+	if (/^REFERRALTRUNCTXT\s+(.*)/) 
+	    { $REFERRALTRUNCTXT.=$1."\n"; next;}
+	if (/^REFERRALENDTXT\s+(.*)/)
+	    { $REFERRALENDTXT.=$1."\n"; next;}
+	if (/^REFERRALTIMEOUT\s+(\d+)/) {$REFERRALTIMEOUT = $1; next}
+	if (/^REFERRALMAXLINES\s+(\d+)/) {$REFERRALMAXLINES = $1; next}
+
 	
 	#
 	# we substract 10 to compensate for the extra bytes
@@ -231,6 +271,11 @@ sub rconf {
 	if (/^KEEPOPEN\s+(\d+)/) {$KEEPOPEN=$1; next;}
 	if (/^NROFNAMES\s+(\d+)/) {$NROFNAMES=$1; next;}
 	if (/^OVERRIDECRYPTEDPW\s+(\S+)/) { $OVERRIDECRYPTEDPW=$1; next; }
+
+	if (/^DUPLICATEPERSONCHECK\s+(\S+)/) { 
+	    $DUPLICATEPERSONCHECK=$1;
+	    next;
+	}
 	
 	# should check value - NOTIFY or ACK
 	if (/^SUPPRESSMESS\s+(\S+)/) { $SUPPRESSMESS = $1; next; }
@@ -242,6 +287,10 @@ sub rconf {
 	
 	if (/^MAILCMD\s+(.*)/) { $MAILCMD=$1; next;}
 
+        if (/^PGPV\s+(.*)/) { $PGPV=$1; next;}
+        if (/^PGPK\s+(.*)/) { $PGPK=$1; next;}
+	if (/^PGPPATH\s+(.*)/) { $PGPPATH=$1; next;}
+
 	if (/^CANUPD\s+(.+)$/) {
 	   foreach (split(/ /, $1)) {
 	      $CANUPD{$_}=1 if ($_);
@@ -387,21 +436,26 @@ sub rconf {
     
     local($j,@tmp);
     local(%ALLPOINTSTO)=();
+    local(%ALLPOINTSTONICATTR)=();
+    local(%ALLPOINTSTOMTATTR)=();
     local(%ALLPOINTSTOATTR)=();
     local(%ALLKEYS)=();
     local(%OBJPOINTSTOTMP);
     local(%OBJPOINTSTOATTRTMP);
+    local(%OBJPOINTSTONICATTRTMP);
+    local(%OBJPOINTSTOMTATTRTMP);
     local(%OBJKEYSTMP);
+    local(%ALLOBJORDEREDTMP);
     
     foreach $i (keys %OBJATSQ) {
      
-       $ALLNICPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /(^| )(ro|pn)( |$)/);
-       $ALLMTPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /(^| )mt( |$)/);
+#       $ALLNICPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /\b(ro|pn)\b/);
+#       $ALLMTPOINTSTO.=" ".$i if ($POINTSTO{$i}=~ /\b(mt)\b/);
        
        #
        # NIC handle DBS'es
        
-       push(@NICHANDLEDBS, $i) if ($OBJATSQ{$i}=~ /(^| )nh( |$)/);  
+       push(@NICHANDLEDBS, $i) if ($OBJATSQ{$i}=~ /\b(nh)\b/);  
        
        #
        # CLASSLESS DBS'es
@@ -417,30 +471,34 @@ sub rconf {
        
        %OBJPOINTSTOTMP=();
        %OBJPOINTSTOATTRTMP=();
+       %OBJPOINTSTONICATTRTMP=();
+       %OBJPOINTSTOMTATTRTMP=();				   
        %OBJKEYSTMP=();
 
        @tmp=grep(!$OBJATSQ{$_}, split(/ /, $KEYS{$i}));
-       # @tmp=split(/ /, $KEYS{$i});
        
        if (@tmp) {
           @KEYS{@tmp}=(1) x @tmp;
           @OBJKEYSTMP{@tmp}=(1) x @tmp;
           @ALLKEYS{@tmp}=(1) x @tmp;
        }
+
        if ($KEYS{$i}) {
           $OBJKEYSTMP{$i}=1;
           $ALLKEYS{$i}=1;
        }
        
-       # print STDERR "tmp: ", join(" ", @tmp)," tmp keys ($i): ",join(" ", @OBJKEYSTMP{@tmp}), "keys: ", join(" ", @KEYS{@tmp}), "\n";
-       
        foreach $j (split(/ /, $OBJATSQ{$i})) {
           
           next if (!$POINTSTO{$j});
           
           $OBJKEYSTMP{$j}=1;
           $ALLPOINTSTOATTR{$j}=1;
+          $ALLPOINTSTONICATTR{$j}=1 if ($POINTSTONIC{$j});
+          $ALLPOINTSTOMTATTR{$j}=1 if ($POINTSTOMT{$j});
           $OBJPOINTSTOATTRTMP{$j}=1;
+	  $OBJPOINTSTONICATTRTMP{$j} = 1 if ($POINTSTONIC{$j});
+	  $OBJPOINTSTOMTATTRTMP{$j} = 1 if ($POINTSTOMT{$j});
            
           @tmp=split(/ /, $POINTSTO{$j});
              
@@ -451,19 +509,37 @@ sub rconf {
              
        $OBJPOINTSTO{$i}=join(" ", keys %OBJPOINTSTOTMP);
        $OBJPOINTSTOATTR{$i}=join(" ", keys %OBJPOINTSTOATTRTMP);
+       $OBJPOINTSTONICATTR{$i}=join(" ", keys %OBJPOINTSTONICATTRTMP);
+       $OBJPOINTSTOMTATTR{$i}=join(" ", keys %OBJPOINTSTOMTATTRTMP);
+       $OBJPOINTSTONICMTATTR{$i}=$OBJPOINTSTONICATTR{$i}." ".$OBJPOINTSTOMTATTR{$i};
        $OBJKEYS{$i}=join(" ", keys %OBJKEYSTMP);
        
        # print STDERR "keys ($i): $OBJKEYS{$i}\npoints to ($i): $OBJPOINTSTO{$i}\n";
        
     }
     
-    $ALLNICPOINTSTO=~ s/^ //;
-    $ALLMTPOINTSTO=~ s/^ //;
-    
-    $ALLPOINTSTO=join(" ", keys %ALLPOINTSTO);
-    $ALLPOINTSTOATTR=join(" ", keys %ALLPOINTSTOATTR);
+#    $ALLNICPOINTSTO=~ s/^ //;
+#    $ALLMTPOINTSTO=~ s/^ //;
+ 
+    $ALLPOINTSTONIC   = 'pn ro';
+    $ALLPOINTSTOMT    = 'mt';
+    $ALLPOINTSTONICMT = $ALLPOINTSTONIC . " " . $ALLPOINTSTOMT;
+   
+    $ALLPOINTSTO = join(" ", keys %ALLPOINTSTO);
+    $ALLPOINTSTOATTR = join(" ", keys %ALLPOINTSTOATTR);
+    $ALLPOINTSTONICATTR = join(" ", keys %ALLPOINTSTONICATTR);
+    $ALLPOINTSTOMTATTR = join(" ", keys %ALLPOINTSTOMTATTR);
+    $ALLPOINTSTONICMTATTR = $ALLPOINTSTONICATTR . " " . $ALLPOINTSTOMTATTR;
     $ALLKEYS=join(" ", keys %ALLOBJKEYS);
     
+    %ALLOBJORDEREDTMP = %OBJATSQ;
+    foreach (split(/ /, $ALLPOINTSTONICMT)) {
+	delete($ALLOBJORDEREDTMP{$_});
+    }
+    @ALLOBJORDERED = sort keys %ALLOBJORDEREDTMP;
+    push(@ALLOBJORDERED, split(/ /, $ALLPOINTSTONICMT));
+    $ALLOBJORDERED = join(" ", @ALLOBJORDERED);
+
     if (%CLASSLESSDBS) {
        
        local($db);
@@ -552,6 +628,17 @@ sub rconf {
       }
     }
 
+    # check if we have PGP
+    $have_pgp = defined($PGPK) && defined($PGPV);
+
+    if ($have_pgp) { 
+      fatalerror("PGPK binary $PGPK is not executable") unless -x $PGPK;
+      fatalerror("PGPV binary $PGPV is not executable") unless -x $PGPV;
+      fatalerror("PGPPATH directory $PGPPATH does not exist") 
+	  unless -d $PGPPATH;
+      $ENV{"PGPPATH"} = $PGPPATH;
+    }
+
     &ReplaceGlobalVars(*RIGHTS);
 
     # 
