@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: syncdb.pl,v 2.13 1998/07/15 18:01:40 joao Exp $
+# $Id: syncdb.pl,v 2.15 1999/01/12 09:57:07 roman Exp $
 #
 #	$RCSfile: syncdb.pl,v $
-#	$Revision: 2.13 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:40 $
+#	$Revision: 2.15 $
+#	$Author: roman $
+#	$Date: 1999/01/12 09:57:07 $
 
 # This is a client that will update objects read from a file directly
 # in the database, without interference of updated.
@@ -47,13 +47,14 @@ require "enread.pl";
 require "enwrite.pl";
 require "misc.pl";
 require "rconf.pl";
+require "dpr.pl";
 
 require "syslog.pl";     # nothing to do with the system 'syslog.pl'
 require "whoisqry.pl";
 
 ## parse command line
 
-Getopt::Std::getopts('h:s:u:V');
+Getopt::Std::getopts('h:p:s:u:p:Vb');
 
 $::WHOIS_HOST = $::RIPEConfig{WHOISHOST};
 $::WHOIS_HOST = $opt_h if $opt_h;
@@ -68,16 +69,19 @@ if ((!$opt_s) || (($opt_u) && ($opt_u!~ /^\d+\:\d+$/))) {
 
   print <<"EOF";
     
-Usage: $PROGRAMNAME [ -h hostname ] -s source [ -u period:delay ]
+Usage: $PROGRAMNAME [ -h hostname ] [ -p portno ] -s source [ -u period:delay ]
    
 Where:
 
 -h hostname      - hostname of server that provides updates.
                    Default - $::RIPEConfig{WHOISHOST}
+-p portno        - port number of server that provides updates.
+                   Default - look up service "whois" in /etc/services
 -s source        - which source to query for
 -u period:delay  - the program will run for 'period' seconds and
                    will do a query every 'delay' seconds
-
+-V               - verbose output
+-b               - prints a lot of useless debugging information
 EOF
 
   exit 1;
@@ -109,7 +113,7 @@ EOF
 # run on low priority, whois server queries have an
 # higher priority
 
-lower_priority;
+&lower_priority();
 
 %entry=();
 
@@ -166,7 +170,7 @@ sub exitsyncdbase {
 sub skiperrorserial {
    local(*entry,$action,$source,$msg)=@_;
    
-   $entry{"pn"}="problem found" if (!&entype(*entry));
+   $entry{"pn"}="problem found" if (!&entype(%entry));
    $entry{"so"}=$source if (!$entry{"so"});
    
    &adderror(*entry,$msg);
@@ -185,7 +189,7 @@ sub doaction {
 
     local(*entry,$type,$action,$source,$serial) = @_;
     
-    print STDERR "syncdbase - doaction($action,$serial) called\n" if $opt_V;
+#    &dpr("doaction($action,$serial) called\n");
     
     local($returncode)=0;
     
@@ -195,20 +199,20 @@ sub doaction {
     local($mirrordb)='mirrordb';
     local(%mirrordb,@mirrordb);
     
-    print STDERR "syncdbase - doaction opening database\n" if $opt_V;
+#    &dpr("doaction opening database\n");
 
-#    local($type)=&entype(*entry);
+#    local($type)=&entype(%entry);
 
     if (&dbopen(*mirrordb, *entry, 1)) {
        # Open classless database
 
-       print STDERR "syncdbase - doaction opening classless db\n" if $opt_V;
+#       &dpr("doaction opening classless db\n");
        &dbclopen(*entry,1) if ($CLASSLESSDBS{$type});
 
        # Looks like we have some locking problem, so let's
        # lock the thing before we do anything else ...
 
-       print STDERR "syncdbase - doaction locking databases\n" if $opt_V;
+#       &dpr("doaction locking databases\n");
 		
        # do we delete or not ?
 
@@ -221,13 +225,13 @@ sub doaction {
        
           if ($action=~ /^$DELETEACTION$/i) {
 
-             print STDERR "syncdbase - doaction deleting entry ($entry{$type})\n" if $opt_V;
+#             &dpr("doaction deleting entry ($entry{$type})\n");
              $dbstat = &dbdel(*mirrordb, *entry, $type, $DELETEOPTION | $NOCHECKSOPTION);
 
           }
           elsif ($action=~ /^$ADDACTION$/i) {
           
-             print STDERR "syncdbase - doaction adding entry ($entry{$type})\n" if $opt_V;
+#             &dpr("doaction adding entry ($entry{$type})\n");
              $dbstat = &dbadd(*mirrordb, *entry, $type, 0);
           
           }
@@ -237,7 +241,7 @@ sub doaction {
        #
        # noop, just print stat if verbose but always print errors!!!
 
-       print STDERR "syncdbase - doaction checking stat\n" if $opt_V;
+#       &dpr("doaction checking stat\n");
 
        if ($dbstat == $E_NOOP) {
           print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " [NOOP]\n\n";
@@ -247,8 +251,8 @@ sub doaction {
           print STDERR "ERROR, incomingserial ($action: $entry{$type}): ", $LOGFILE{"SERIALINCOMINGDIR"}, $serial, " ", $MESSAGE[$dbstat], "\n\n";
           &skiperrorserial(*entry,$action,$source,$MESSAGE[$dbstat]);
        }
-       elsif ($opt_V) {
-          print STDERR "OK, ($action: $entry{$type}) serial: $serial\n";
+       else {
+#          &dpr("OK, ($action: $entry{$type}) serial: $serial\n");
        }
 
        &dbclose(*mirrordb);
@@ -277,7 +281,7 @@ sub UpdateVersionOne {
    
    my $basename = $LOGFILE{"SERIALINCOMINGDIR"}.$source;
    
-   print STDERR "basename: $basename source: $source first: $first last: $last\n" if $opt_V;
+#   &dpr("basename: $basename source: $source first: $first last: $last\n");
       
    $i=$first;
    $line=<$input>;
@@ -293,7 +297,7 @@ sub UpdateVersionOne {
           ($line!~ /^\s*$/) &&
           ($line!~ /^\%END/)) {
    
-      print STDERR "update: $basename.$i\n" if $opt_V;
+#      &dpr("update: $basename.$i\n");
       
       if ($line=~ /^$ADDACTION$/i) {
          $action=$ADDACTION;
@@ -325,8 +329,6 @@ sub UpdateVersionOne {
 	close(OUTP);
       }
 
-      print STDERR "action: $action\n" if $opt_V;  
-      
       &doaction(*oldentry,$oldtype,$oldaction,$source,$oldi) if ($i!=$first);
    
       %oldentry=%entry;
@@ -346,7 +348,6 @@ sub UpdateVersionOne {
 
    if ($line=~ /^\s*$/) {
       $line=<TMPFILE>;
-      print STDERR "read extra line: ", $line if $opt_V;
    }
 
    if ($STOPUPDATING) {
@@ -477,11 +478,8 @@ if ($opt_u) {
      srand;
      my $random = abs rand(60);
 
-     print STDERR "Sleeping for $random seconds..." if $opt_V;
-
      sleep $random;
 
-     print STDERR "done\n" if $opt_V;
    }
    
 }
@@ -541,7 +539,6 @@ QUERY: while ((!$TIMEOUT) && (!$STOPUPDATING)) {
    
 LINE:   
    while (($line=<TMPFILE>) && ($line!~ /^\%START/)) { 
-      print STDERR "skip:", $line if $opt_V;
    
       ## If there were no updates available we get '% Warning (1)
       ## Just close the TMPFILE and do the next query
@@ -549,6 +546,7 @@ LINE:
 
       if ($line =~ /\s*%\s+Warning\s+\(1\)/) {
 	close TMPFILE;
+	&exitsyncdbase("No more updates available") if (!$period);
 	next QUERY;
       }
 
@@ -593,13 +591,11 @@ LINE:
    }
    else {
    
-      print STDERR "last:", $line if $opt_V;
-
       #
       # call the right updating procedure
    
       if ($line=~ /^\%START\s+Version:\s*(\d+)\s+/) {
-         print STDERR "found: ", $line if $opt_V;
+
          $version=$1;
    
          if ($version==1) {
@@ -636,7 +632,6 @@ LINE:
     while (!$TIMEOUT && $oldmtime==$mtime) {
       sleep $delay;
       $mtime=(stat($SYNCFASTMODE))[9];
-      print STDERR "old: $oldmtime mtime: $mtime\n" if ($opt_V);
     }
    
   }
