@@ -20,12 +20,12 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: updatecheck.pl,v 2.2 1998/07/15 18:01:43 joao Exp $
+# $Id: updatecheck.pl,v 2.3 1998/12/09 14:39:28 roman Exp $
 #
 #	$RCSfile: updatecheck.pl,v $
-#	$Revision: 2.2 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:43 $
+#	$Revision: 2.3 $
+#	$Author: roman $
+#	$Date: 1998/12/09 14:39:28 $
 
 require "defines.pl";
 require "adderror.pl";
@@ -115,7 +115,7 @@ sub updatecheck {
     local(*db, *oldobject, *newobject, $type, $options)=@_;
 
     return $O_OK if ($options & $NOCHECKSOPTION);
-
+#    &dpr("override option: ", ($options & $OVERRIDEOPTION), "\n");
     local($returncode)=$O_OK;
     
     #
@@ -123,8 +123,9 @@ sub updatecheck {
     # a maintainer but don't have one in the old object
                 
     return $E_NOAUTOUPDATE if ((!($options & $OVERRIDEOPTION)) && 
-                               ($OBJMAND{$type}=~ /^(^| )mb( |$)/) && 
-                               (!defined($oldobject{"mb"})));
+                               ($OBJMAND{$type}=~ /\bmb\b/) && 
+                               (!defined($oldobject{"mb"})) &&
+			       (!($options & $NEWOPTION)));
 
     #
     # If this is a maintainer object, bounce it of to the human mailbox
