@@ -20,18 +20,18 @@
 # AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #
-# $Id: whois.pl,v 2.5 1998/07/15 18:01:44 joao Exp $
+# $Id: whois.pl,v 2.7 1998/12/09 14:39:28 roman Exp $
 #
 #	$RCSfile: whois.pl,v $
-#	$Revision: 2.5 $
-#	$Author: joao $
-#	$Date: 1998/07/15 18:01:44 $
+#	$Revision: 2.7 $
+#	$Author: roman $
+#	$Date: 1998/12/09 14:39:28 $
 
 # This is a very simple whois client, but it knows the new server arguments
 
 require "getopts.pl";
 
-&Getopts('acFg:h:i:LmMp:rs:St:v:T:');
+&Getopts('aFg:h:i:LmMp:rRs:St:v:T:');
 
 if ((!@ARGV) && (!$opt_t) && (!$opt_g) && (!$opt_v) && (!(($opt_g) && ($opt_t)))) {
     
@@ -43,7 +43,6 @@ Usage: whois [-acFLmMrSv] [-h hostname] [-s sources] [-T types] [-i attr] keys
 Where:
 
 -a                         search all databases
--c                         show changed attributes in objects
 -F                         fast raw output
 -h hostname                search alternate server
 -i attr[[,attr] ... ]      do an inverse lookup for specified attributes
@@ -52,6 +51,7 @@ Where:
 -M                         find all More specific matches
 -p port                    port to connect to
 -r                         turn off recursive lookups
+-R                         do not trigger referral mechanism
 -s source[[,source] ... ]  search databases with source 'source'
 -S                         tell server to leave out 'syntactic sugar'
 -t type                    requests template for object of type 'type'
@@ -83,7 +83,6 @@ if ($opt_m) {
 local($query)="";
 
 $query.="-a "            if ($opt_a);
-$query.="-c "            if ($opt_c);
 #
 #  undocumented option, get specified updates:
 #
@@ -96,6 +95,7 @@ $query.="-L "            if ($opt_L);
 $query.="-m "            if ($opt_m);
 $query.="-M "            if ($opt_M);
 $query.="-r "            if ($opt_r);
+$query.="-R "            if ($opt_R);
 $query.="-S "            if ($opt_S);
 $query.="-s ".$opt_s." " if ($opt_s);
 $query.="-t ".$opt_t." " if ($opt_t);
@@ -109,7 +109,7 @@ $query.="-T ".$opt_T." " if ($opt_T);
 # RIPE whois server
 
 if (($opt_h=~ /(ripe\.net|ra\.net|apnic\.net|mci\.net|isi\.edu|garr\.it|ans\.net)$/i) ||
-    $opt_a || $opt_c || $opt_g || $opt_F || $opt_i || $opt_m || $opt_M ||
+    $opt_a || $opt_g || $opt_F || $opt_i || $opt_m || $opt_M || $opt_R ||
     $opt_L || $opt_r || $opt_s || $opt_S || $opt_t || $opt_v || $opt_T) {
     
    $query.="-Vwp2.0 ";
